aboutsummaryrefslogtreecommitdiff
path: root/gdb/solib-frv.c
diff options
context:
space:
mode:
authorSimon Marchi <simon.marchi@efficios.com>2024-02-05 15:18:34 -0500
committerSimon Marchi <simon.marchi@efficios.com>2024-02-05 16:10:15 -0500
commit6cedf3bcbf9d8ac88147fdb9b0765a206191a282 (patch)
treee6ba766a7f51f3b0aba680c7182e54d6345baafa /gdb/solib-frv.c
parent7b323785ef83a7d6f023909fe21b7983651c3f27 (diff)
downloadgdb-6cedf3bcbf9d8ac88147fdb9b0765a206191a282.zip
gdb-6cedf3bcbf9d8ac88147fdb9b0765a206191a282.tar.gz
gdb-6cedf3bcbf9d8ac88147fdb9b0765a206191a282.tar.bz2
gdb: rename target_so_ops to solib_ops
I don't like the name `target_so_ops`, because: - The name `target` is so overloaded, and in this case it's not even related to target_ops or anything else called "target". - We do have an implementation that actually fetches solibs from the target (solib_target_so_op in solib-target.c), so it's confusing for the "base class" to be called target_something as well. Rename to solib_ops. Change-Id: I46a983d44e81400470e22deb09aaf26ad8a3587f Approved-By: Tom Tromey <tom@tromey.com>
Diffstat (limited to 'gdb/solib-frv.c')
-rw-r--r--gdb/solib-frv.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gdb/solib-frv.c b/gdb/solib-frv.c
index 9a098f7..c425b33 100644
--- a/gdb/solib-frv.c
+++ b/gdb/solib-frv.c
@@ -237,7 +237,7 @@ static void frv_relocate_main_executable (void);
static CORE_ADDR main_got (void);
static int enable_break2 (void);
/* Implement the "open_symbol_file_object" target_so_ops method. */
static int
open_symbol_file_object (int from_tty)
@@ -304,7 +304,7 @@ lm_base (void)
}
/* Implement the "current_sos" target_so_ops method. */
static intrusive_list<solib>
frv_current_sos ()
@@ -1073,7 +1073,7 @@ frv_fetch_objfile_link_map (struct objfile *objfile)
return 0;
}
-const struct target_so_ops frv_so_ops =
+const solib_ops frv_so_ops =
{
frv_relocate_section_addresses,
nullptr,
@@ -237,7 +237,7 @@ static void frv_relocate_main_executable (void);
static CORE_ADDR main_got (void);
static int enable_break2 (void);
-/* Implement the "open_symbol_file_object" target_so_ops method. */
+/* Implement the "open_symbol_file_object" solib_ops method. */
static int
open_symbol_file_object (int from_tty)
@@ -304,7 +304,7 @@ lm_base (void)
}
-/* Implement the "current_sos" target_so_ops method. */
+/* Implement the "current_sos" solib_ops method. */
static intrusive_list<solib>
frv_current_sos ()